declare const BLOCK_NUMBERS: readonly [1, 2, 3, 4, 5, 6, 7];
declare type BlockNumber = typeof BLOCK_NUMBERS[number];
declare type Item = {
    type: "image";
    url: string;
} | {
    type: "text";
    text: string;
};
declare type RawResults<CategoryT, TargetT> = {
    blocks: Record<BlockNumber, {
        completionTimeMs: number;
        correct: boolean;
    }[]>;
    positiveScoreAssociations: [
        {
            target: TargetT;
            category: CategoryT;
        },
        {
            target: TargetT;
            category: CategoryT;
        }
    ];
    negativeScoreAssociations: [
        {
            target: TargetT;
            category: CategoryT;
        },
        {
            target: TargetT;
            category: CategoryT;
        }
    ];
};
declare type Results<CategoryT, TargetT> = {
    type: "invalid";
    reason: "no-low-latency-trials" | "too-many-high-latency-trials";
} | {
    type: "valid";
    d: number;
    association: [
        {
            target: TargetT;
            category: CategoryT;
        },
        {
            target: TargetT;
            category: CategoryT;
        }
    ];
};
declare type Choice = "left" | "right";
declare type TrialOption<CategoryT, TargetT> = {
    category?: CategoryT;
    target?: TargetT;
};
declare type IATStage<CategoryT, TargetT> = {
    testComplete: false;
    block: number;
    trial: number;
    left: TrialOption<CategoryT, TargetT>;
    right: TrialOption<CategoryT, TargetT>;
    item: Item;
    correctChoice: Choice;
    next: (completionTimeMs: number, correct: boolean) => IATStage<CategoryT, TargetT>;
} | {
    testComplete: true;
    rawResults: RawResults<CategoryT, TargetT>;
};
declare function IAT<CategoryT extends string, TargetT extends string>(options: {
    categories: Record<CategoryT, Item[]>;
    targets: Record<TargetT, Item[]>;
    trialsPerBlock: Record<BlockNumber, number>;
}): IATStage<CategoryT, TargetT>;
declare function getResults<CategoryT, TargetT>(rawResults: RawResults<CategoryT, TargetT>): Results<CategoryT, TargetT>;

export { BLOCK_NUMBERS, BlockNumber, Choice, IAT, IATStage, Item, RawResults, Results, TrialOption, getResults };
